@@ -6,10 +6,23 @@ from flask.ext.admin.form.fields import Select2Field
 
 _unset_value = object()
 
+class OrderViewMixin:
+    pass
 
 config = {
     "name": "Order",
-    "description": "Manage order of your models",    
+    "description": "Manage order of your models",
+    "admin": {
+        "view_subclass": OrderViewMixin,
+        "template": {
+            "modelview.edit_view": {
+                "tail_js":"ordering-inline-tail.html"
+            },
+            "modelview.create_view": {
+                "tail_js": "ordering-inline-tail.html"
+            }
+        }
+    } 
 }
 '''"extend": {
     "admin": {
@@ -114,6 +127,7 @@ class OrderingInlineFieldList(InlineModelFormList):
                 data = self.default
 
         self.object_data = data
+        print formdata
 
         if formdata:  
             indices = sorted(set(self._extract_indices(self.name, formdata)))
